pub struct BcryptString(/* private fields */);Expand description
A bcrypt hash as stored in the database.
Emits $2a$ rather than the crate default $2b$, as pgcrypto silently falls back to DES for $2b$.
Implementations
Sourceimpl BcryptString
impl BcryptString
pub async fn hash(password: &str) -> Result<Self, Error>
pub async fn verify(&self, password: &str) -> Result<bool, Error>
Sourcepub async fn verify_dummy(password: &str) -> Result<(), Error>
pub async fn verify_dummy(password: &str) -> Result<(), Error>
Burns the same time a real verification would so a missing user or a user without a password is indistinguishable from a wrong password.
pub fn needs_rehash(&self) -> bool